@@ -6,13 +6,13 @@ from .underfull_duration import underfull_duration
 
 
 def close_container(container: abjad.Container):
-    r"""Mutates an input container (of type ``abjad.Container`` or child class)
+    r"""Mutates an input container (of type |abjad.Container| or child class)
     in place and has no return value; this function changes the time signature
-    of the last bar of an underfull in order to make it full.
+    of the last measure of an underfull in order to make it full.
 
-    Example:
-        Returns the missing duration of the last bar of any container or child
-        class. If no time signature is encountered, it uses LilyPond's
+    Basic usage:
+        Returns the missing duration of the last measure of any container or
+        child class. If no time signature is encountered, it uses LilyPond's
         convention and considers the container as in 4/4.
 
         >>> container1 = abjad.Container(r"c'4 d'4 e'4 f'4")
@@ -69,7 +69,7 @@ def close_container(container: abjad.Container):
 
         .. figure:: ../_images/image-close_container-4.png
 
-    Example:
+    Time signature changes:
         Handles any time signatures as well as changes of time signature.
 
         >>> container1 = abjad.Container(r"\time 4/4 c'4 d'4 e'4 f'4 g'")
@@ -117,8 +117,8 @@ def close_container(container: abjad.Container):
 
         Notice that the time signatures in the output are commented out with
         ``%%%``. This is because Abjad only applies time signatures to
-        containers that belong to a ``abjad.Staff``. The present function works
-        with either ``abjad.Container`` and ``abjad.Staff``.
+        containers that belong to a |abjad.Staff|. The present function works
+        with either |abjad.Container| and |abjad.Staff|.
 
         >>> container = abjad.Container(r"\time 4/4 c'4 d'4 e'4 f'4 g'4")
         >>> auxjad.close_container(container)
@@ -132,6 +132,9 @@ def close_container(container: abjad.Container):
             %%% \time 1/4 %%%
             g'4
         }
+
+        .. figure:: ../_images/image-close_container-8.png
+
         >>> staff = abjad.Staff([container])
         >>> abjad.f(container)
         {
@@ -144,7 +147,9 @@ def close_container(container: abjad.Container):
             g'4
         }
 
-    Example:
+        .. figure:: ../_images/image-close_container-9.png
+
+    Partial time signatures:
         Correctly handles partial time signatures.
 
         >>> container = abjad.Container(r"c'4 d'4 e'4 f'4 g'4")
@@ -167,16 +172,26 @@ def close_container(container: abjad.Container):
 
     ..  error::
 
-        If a container is malformed, i.e. it has an underfilled bar before a
-        time signature change, the function raises a ``ValueError`` exception.
+        If a container is malformed, i.e. it has an underfilled measure before
+        a time signature change, the function raises a :exc:`ValueError`
+        exception.
 
         >>> container = abjad.Container(r"\time 5/4 g''1 \time 4/4 f'4")
         >>> auxjad.close_container(container)
-        ValueError: 'container' is malformed, with an underfull bar preceeding
-        a time signature change
+        ValueError: 'container' is malformed, with an underfull measure
+        preceeding a time signature change
+
+    ..  warning::
+
+        The input container must be a contiguous logical voice. When dealing
+        with a container with multiple subcontainers (e.g. a score containings
+        multiple staves), the best approach is to cycle through these
+        subcontainers, applying this function to them individually.
     """
     if not isinstance(container, abjad.Container):
         raise TypeError("argument must be 'abjad.Container' or child class")
+    if not abjad.select(container).leaves().are_contiguous_logical_voice():
+        raise ValueError("argument must be contiguous logical voice")
     if not container_is_full(container):
         missing_duration = underfull_duration(container)
         leaves = abjad.select(container).leaves()
