@@ -6,10 +6,10 @@ def containers_are_equal(container1: abjad.Container,
                          *,
                          include_indicators: bool = False,
                          ) -> bool:
-    r"""Returns a ``bool`` representing whether two input containers (of type
-    ``abjad.Container`` or child class) are identical or not.
+    r"""Returns a :obj:`bool` representing whether two input containers (of
+    type |abjad.Container| or child class) are identical or not.
 
-    Example:
+    Basic usage:
         When the pitches and effective durations of all leaves in both
         containers are identical, this function returns ``True``:
 
@@ -18,7 +18,7 @@ def containers_are_equal(container1: abjad.Container,
         >>> auxjad.containers_are_equal(container1, container2)
         True
 
-    Example:
+    Effective durations:
         Even if all leaves of both containers are identical in relation to both
         pitches and written durations, the function considers the effective
         durations. This means that situations like the one below do not yield a
@@ -30,7 +30,7 @@ def containers_are_equal(container1: abjad.Container,
         >>> auxjad.containers_are_equal(container1, container2)
         False
 
-    Example:
+    ``include_indicators``:
         By default, this function ignores indicators, so the containers in the
         example below are understood to be identical:
 
@@ -39,7 +39,6 @@ def containers_are_equal(container1: abjad.Container,
         >>> auxjad.containers_are_equal(container1, container2)
         True
 
-    Example:
         Setting the argument ``include_indicators`` to ``True`` forces the
         function to include indicators in its comparison. In that case, the
         containers in the example above are not considered identical any
@@ -53,7 +52,7 @@ def containers_are_equal(container1: abjad.Container,
         ...                             )
         True
 
-    Example:
+    Grace notes:
         This function also handles grace notes:
 
         >>> container1 = abjad.Staff(r"c'4 d'4 e'4 f'4")
@@ -80,6 +79,17 @@ def containers_are_equal(container1: abjad.Container,
         ...                          "f'4 <g' a'>2 r2")
         >>> auxjad.containers_are_equal(container1, container2)
         True
+
+    ..  note::
+
+        It is important to note it is the contents of the containers which are
+        compared, so containers of different classes can still return a
+        ``True`` value.
+
+        >>> container1 = abjad.Container(r"c'4 d'4 e'4 f'4")
+        >>> container2 = abjad.Staff(r"c'4 d'4 e'4 f'4")
+        >>> auxjad.containers_are_equal(container1, container2)
+        True
     """
     if not isinstance(container1, abjad.Container):
         raise TypeError("first positional argument must be 'abjad.Container' "
