@@ -7,8 +7,10 @@ from .fill_with_rests import fill_with_rests as fill_with_rests_function
 
 
 def enforce_time_signature(container: abjad.Container,
-                           time_signatures: Union[abjad.TimeSignature, tuple,
-                                                  list],
+                           time_signatures: Union[abjad.TimeSignature,
+                                                  tuple,
+                                                  list,
+                                                  ],
                            *,
                            cyclic: bool = False,
                            fill_with_rests: bool = True,
@@ -18,11 +20,11 @@ def enforce_time_signature(container: abjad.Container,
                            maximum_dot_count: Optional[int] = None,
                            rewrite_tuplets: bool = True,
                            ):
-    r"""Mutates an input container (of type ``abjad.Container`` or child class)
+    r"""Mutates an input container (of type |abjad.Container| or child class)
     in place and has no return value; this function applies a time signature
-    (or a list of time signatures) to the input container.
+    (or a :obj:`list` of time signatures) to the input container.
 
-    Example:
+    Basic usage:
         The function mutates a container in place, applying a time signature
         to it.
 
@@ -51,10 +53,10 @@ def enforce_time_signature(container: abjad.Container,
 
         .. figure:: ../_images/image-enforce_time_signature-2.png
 
-    Example:
-        The second positional argument can take either ``abjad.TimeSignature``
-        or a ``tuple`` for a single time signature (for multiple time
-        signatures, use a ``list`` as shown further below). By default,
+    Single value for second positional argument:
+        The second positional argument can take either |abjad.TimeSignature|
+        or a :obj:`tuple` for a single time signature (for multiple time
+        signatures, use a :obj:`list` as shown further below). By default,
         rests will be appended to the end of the staff if necessary.
 
         >>> staff = abjad.Staff(r"c'1 d'1")
@@ -83,9 +85,9 @@ def enforce_time_signature(container: abjad.Container,
 
         .. figure:: ../_images/image-enforce_time_signature-4.png
 
-    Example:
+    ``close_container``:
         Set the optional keyword argument ``close_container`` to ``True`` in
-        order to adjust the last bar's time signature instead of filling it
+        order to adjust the last measure's time signature instead of filling it
         with rests.
 
         >>> staff = abjad.Staff(r"c'1 d'1 e'1 f'1")
@@ -125,11 +127,11 @@ def enforce_time_signature(container: abjad.Container,
 
         .. figure:: ../_images/image-enforce_time_signature-6.png
 
-    Example:
-        Alternatively, to leave the last bar as it is input (i.e. not filling
-        it with rests nor adjusting the time signature), set the optional
-        keyword argument ``fill_with_rests`` to ``False`` (default value is
-        ``True``).
+    ``fill_with_rests``:
+        Alternatively, to leave the last measure as it is input (i.e. not
+        filling it with rests nor adjusting the time signature), set the
+        optional keyword argument ``fill_with_rests`` to ``False`` (default
+        value is ``True``).
 
         >>> staff = abjad.Staff(r"c'1 d'1 e'1 f'1")
         >>> abjad.f(staff)
@@ -167,9 +169,9 @@ def enforce_time_signature(container: abjad.Container,
 
         .. figure:: ../_images/image-enforce_time_signature-8.png
 
-    Example:
-        The second argument can also take a ``list`` of ``abjad.TimeSignature``
-        or ``tuple``.
+    Multiple values for second positional argument:
+        The second argument can also take a :obj:`list` of
+        |abjad.TimeSignature| or :obj:`tuple`.
 
         >>> staff = abjad.Staff(r"c'1 d'1")
         >>> abjad.f(staff)
@@ -198,9 +200,9 @@ def enforce_time_signature(container: abjad.Container,
 
         .. figure:: ../_images/image-enforce_time_signature-10.png
 
-    Example:
+    Repeated time signatures:
         Consecutive identical time signatures are omitted. Also note that time
-        signatures can also be represented as a ``list`` of ``tuples``.
+        signatures can also be represented as a :obj:`list` of :obj:`tuple`'s.
 
         >>> staff = abjad.Staff(r"c'1 d'1 e'1 f'1")
         >>> abjad.f(staff)
@@ -276,9 +278,9 @@ def enforce_time_signature(container: abjad.Container,
 
         .. figure:: ../_images/image-enforce_time_signature-14.png
 
-    Example:
-        To cycle through the list of time signatures until the container is
-        exhausted, set the optional keyword argument ``cyclic`` to ``True``.
+    ``cyclic``:
+        To cycle through the :obj:`list` of time signatures until the container
+        is exhausted, set the optional keyword argument ``cyclic`` to ``True``.
 
         >>> staff = abjad.Staff(r"c'1 d'1 e'1 f'1")
         >>> abjad.f(staff)
@@ -346,9 +348,9 @@ def enforce_time_signature(container: abjad.Container,
 
         .. figure:: ../_images/image-enforce_time_signature-16.png
 
-    Example:
-        By default, this function appled the mutation ``rewrite_meter()`` to
-        its output.
+    ``disable_rewrite_meter``:
+        By default, this function applies the mutation
+        |abjad.mutate().rewrite_meter()| to its output.
 
         >>> staff = abjad.Staff(r"c'1 ~ c'4 r8 d'4. e'4")
         >>> time_signatures = [abjad.TimeSignature((5, 4)),
@@ -398,7 +400,7 @@ def enforce_time_signature(container: abjad.Container,
 
         .. figure:: ../_images/image-enforce_time_signature-18.png
 
-    Example:
+    Tuplets:
         The function handles tuplets, even if they must be split.
 
         >>> staff = abjad.Staff(r"\times 2/3 {c'2 d'2 e'2} f'1")
@@ -440,7 +442,7 @@ def enforce_time_signature(container: abjad.Container,
 
         .. figure:: ../_images/image-enforce_time_signature-20.png
 
-    Example:
+    Time signatures in the input container:
         Note that any time signatures in the input container will be ignored.
 
         >>> staff = abjad.Staff(r"\time 3/4 c'2. d'2. e'2. f'2.")
@@ -502,9 +504,9 @@ def enforce_time_signature(container: abjad.Container,
 
         .. figure:: ../_images/image-enforce_time_signature-22.png
 
-    Example:
+    Tweaking |abjad.mutate().rewrite_meter()|:
         This function uses the default logical tie splitting algorithm from
-        abjad's ``rewrite_meter()``.
+        |abjad.mutate().rewrite_meter()|.
 
         >>> staff = abjad.Staff(r"c'4. d'8 e'2")
         >>> auxjad.enforce_time_signature(staff,
@@ -541,18 +543,18 @@ def enforce_time_signature(container: abjad.Container,
 
         .. figure:: ../_images/image-enforce_time_signature-24.png
 
-        Other arguments available for tweaking the output of abjad's
-        ``rewrite_meter()`` are ``maximum_dot_count`` and ``rewrite_tuplets``,
-        which work exactly as the identically named arguments of
-        ``rewrite_meter()``.
+        Other arguments available for tweaking the output of
+        |abjad.mutate().rewrite_meter()| are ``maximum_dot_count`` and
+        ``rewrite_tuplets``, which work exactly as the identically named
+        arguments of |abjad.mutate().rewrite_meter()|.
 
     .. note::
 
         It is important to notice that the time signatures in the output are
-        commented out with ``%%%`` if the input is of type ``abjad.Container``.
+        commented out with ``%%%`` if the input is of type |abjad.Container|.
         This is because Abjad only applies time signatures to containers that
-        belong to a ``abjad.Staff``. The present function works with either
-        ``abjad.Container`` and ``abjad.Staff``.
+        belong to a |abjad.Staff|. The present function works with either
+        |abjad.Container| and |abjad.Staff|.
 
         >>> container = abjad.Container(r"\time 4/4 c'4 d'4 e'4 f'4 g'4")
         >>> abjad.f(container)
@@ -588,10 +590,19 @@ def enforce_time_signature(container: abjad.Container,
             g'4
             r4
         }
+
+    ..  warning::
+
+        The input container must be a contiguous logical voice. When dealing
+        with a container with multiple subcontainers (e.g. a score containings
+        multiple staves), the best approach is to cycle through these
+        subcontainers, applying this function to them individually.
     """
     if not isinstance(container, abjad.Container):
         raise TypeError("first argument must be 'abjad.Container' or "
                         "child class")
+    if not abjad.select(container).leaves().are_contiguous_logical_voice():
+        raise ValueError("first argument must be contiguous logical voice")
     if isinstance(time_signatures, list):
         time_signatures_ = time_signatures[:]
     else:
@@ -599,8 +610,7 @@ def enforce_time_signature(container: abjad.Container,
     if time_signatures_[0] is None:
         raise ValueError("first element of the input list must not be 'None'")
     # converting all elements to abjad.TimeSignature
-    for index in range(len(time_signatures_)):
-        time_signature = time_signatures_[index]
+    for index, time_signature in enumerate(time_signatures_):
         if time_signature is None:
             previous_ts_duration = time_signatures_[index - 1].pair
             time_signatures_[index] = abjad.TimeSignature(previous_ts_duration)
@@ -636,32 +646,30 @@ def enforce_time_signature(container: abjad.Container,
     # slice container at the places where time signatures change
     durations = [time_signature.duration for time_signature
                  in time_signatures_]
-    if cyclic:
-        abjad.mutate(container[:]).split(durations, cyclic=True)
-    else:
+    if not cyclic:
         while sum(durations) < abjad.inspect(container).duration():
             durations.append(durations[-1])
-        abjad.mutate(container[:]).split(durations)
+    abjad.mutate(container[:]).split(durations, cyclic=cyclic)
     # attach new time signatures
     previous_ts = None
-    ts_index = 0
+    index = 0
     duration = abjad.Duration(0)
     previous_ts_duration = abjad.Duration(0)
     for leaf in abjad.select(container).leaves():
         if duration == previous_ts_duration:
             duration = abjad.Duration(0)
-            previous_ts_duration = durations[ts_index]
-            if partial_time_signature is not None and ts_index in (0, 1):
+            previous_ts_duration = durations[index]
+            if partial_time_signature is not None and index in (0, 1):
                 ts = partial_time_signature
             else:
-                ts = time_signatures_[ts_index]
+                ts = time_signatures_[index]
             if ts != previous_ts:
                 abjad.attach(ts, leaf)
             previous_ts = ts
-            ts_index += 1
-            if ts_index == len(time_signatures_):
+            index += 1
+            if index == len(time_signatures_):
                 if cyclic:
-                    ts_index = 0
+                    index = 0
                 else:
                     break
         duration += abjad.inspect(leaf).duration()
