@@ -2,13 +2,13 @@ import abjad
 
 
 def remove_repeated_time_signatures(container: abjad.Container):
-    r"""Mutates an input container (of type ``abjad.Container`` or child class)
+    r"""Mutates an input container (of type |abjad.Container| or child class)
     in place and has no return value; this function removes all consecutive
     repeated time signatures.
 
-    Example:
-        When two consecutive bars have identical time signatures, the second
-        one is removed:
+    Basic usage:
+        When two consecutive measures have identical time signatures, the
+        second one is removed:
 
         >>> staff = abjad.Staff(r"c'4 d'8 | c'4 d'8")
         >>> abjad.attach(abjad.TimeSignature((3, 8)), staff[0])
@@ -39,9 +39,9 @@ def remove_repeated_time_signatures(container: abjad.Container):
 
         .. figure:: ../_images/image-remove_repeated_time_signatures-2.png
 
-    Example:
+    Time signature structure:
         The function also removes time signatures that are separated by an
-        arbitrary number of bars without one:
+        arbitrary number of measures without one:
 
         >>> staff = abjad.Staff(r"c'4 d'8 e'4. c'4 d'8")
         >>> abjad.attach(abjad.TimeSignature((3, 8)), staff[0])
@@ -74,7 +74,7 @@ def remove_repeated_time_signatures(container: abjad.Container):
 
         .. figure:: ../_images/image-remove_repeated_time_signatures-4.png
 
-    Example:
+    Subcontainers:
         The input container can also handle subcontainers, including cases in
         which the time signatures are attached to leaves of subcontainers:
 
@@ -115,9 +115,18 @@ def remove_repeated_time_signatures(container: abjad.Container):
         }
 
         .. figure:: ../_images/image-remove_repeated_time_signatures-6.png
+
+    ..  warning::
+
+        The input container must be a contiguous logical voice. When dealing
+        with a container with multiple subcontainers (e.g. a score containings
+        multiple staves), the best approach is to cycle through these
+        subcontainers, applying this function to them individually.
     """
     if not isinstance(container, abjad.Container):
         raise TypeError("argument must be 'abjad.Container' or child class")
+    if not abjad.select(container).leaves().are_contiguous_logical_voice():
+        raise ValueError("argument must be contiguous logical voice")
 
     measures = abjad.select(container[:]).group_by_measure()
 
