@@ -6,11 +6,11 @@ def respell_chord(chord: abjad.Chord,
                   include_multiples: bool = False,
                   respell_by_pitch_class: bool = False,
                   ):
-    r"""Mutates an input chord (of type ``abjad.Chord`` or child class) in
+    r"""Mutates an input chord (of type |abjad.Chord| or child class) in
     place and has no return value; this function changes the accidentals of
     individual pitches of a chord in order to avoid augmented unisons.
 
-    Example:
+    Basic usage:
         To use this function, apply it to a chord that contains augmented
         unisons.
 
@@ -21,10 +21,10 @@ def respell_chord(chord: abjad.Chord,
 
         .. figure:: ../_images/image-respell_chord-1.png
 
-    Example:
-        The example below shows the default spelling of 2-note chords by
-        ``Abjad`` in the upper staff, and the respelt 2-note chords in the
-        bottom staff.
+    2-note chords:
+        The example below shows the default spelling of 2-note chords in
+        Abjad in the upper staff, and the respelt 2-note chords in the bottom
+        staff.
 
         >>> staff1 = abjad.Staff()
         >>> staff2 = abjad.Staff()
@@ -76,7 +76,7 @@ def respell_chord(chord: abjad.Chord,
 
         .. figure:: ../_images/image-respell_chord-2.png
 
-    Example:
+    augmented unissons in larger chords:
         The function looks for all augmented unissons in chords of 3 or more
         pitches:
 
@@ -108,7 +108,7 @@ def respell_chord(chord: abjad.Chord,
 
         .. figure:: ../_images/image-respell_chord-4.png
 
-    Example:
+    ``include_multiples``:
         By default, this function only changes spelling for pitches that are
         1 semitone apart.
 
@@ -143,7 +143,7 @@ def respell_chord(chord: abjad.Chord,
 
         .. figure:: ../_images/image-respell_chord-6.png
 
-    Example:
+    ``respell_by_pitch_class``:
         By default, when this function changes the spelling of a pitch, it does
         not change the spelling of all other pitches with the same pitch-class.
 
@@ -209,13 +209,13 @@ def respell_chord(chord: abjad.Chord,
                 else:
                     # respelling all matching pitch-classes
                     if p1.accidental == abjad.Accidental('f'):
-                        for k, p in enumerate(chord.written_pitches):
+                        for j, p in enumerate(chord.written_pitches):
                             if p.pitch_class == p1.pitch_class:
-                                pitch_accidentals[k] = abjad.Accidental('s')
+                                pitch_accidentals[j] = abjad.Accidental('s')
                     elif p1.accidental == abjad.Accidental(''):
-                        for k, p in enumerate(chord.written_pitches):
+                        for j, p in enumerate(chord.written_pitches):
                             if p.pitch_class == p2.pitch_class:
-                                pitch_accidentals[k] = abjad.Accidental('f')
+                                pitch_accidentals[j] = abjad.Accidental('f')
     else:
         # dealing with augmented unisons as well as augmented 8as, 15ths, etc.
         for i in range(len(chord.written_pitches) - 1):
