@@ -4,11 +4,11 @@ from .remove_empty_tuplets import remove_empty_tuplets
 
 
 def rests_to_multimeasure_rest(container: abjad.Container):
-    r"""Mutates an input container (of type ``abjad.Container`` or child class)
-    in place and has no return value; this function looks for bars filled with
-    regular rests and converts them into an ``abjad.MultimeasureRest``.
+    r"""Mutates an input container (of type |abjad.Container| or child class)
+    in place and has no return value; this function looks for measures filled
+    with regular rests and converts them into an |abjad.MultimeasureRest|.
 
-    Example:
+    Basic usage:
         Converts any measure filled with regular rests into a measure with a
         single multi-measure rest.
 
@@ -21,7 +21,7 @@ def rests_to_multimeasure_rest(container: abjad.Container):
 
         .. figure:: ../_images/image-rests_to_multimeasure_rest-1.png
 
-    Example:
+    Multiple rests:
         Works with measures with multiple regular rests.
 
         >>> container = abjad.Container(r"r2 r8.. r32 r16 r8 r16")
@@ -49,8 +49,8 @@ def rests_to_multimeasure_rest(container: abjad.Container):
 
         Notice that the time signatures in the output are commented out with
         ``%%%``. This is because Abjad only applies time signatures to
-        containers that belong to a ``abjad.Staff``. The present function works
-        with either ``abjad.Container`` and ``abjad.Staff``.
+        containers that belong to a |abjad.Staff|. The present function works
+        with either |abjad.Container| and |abjad.Staff|.
 
         >>> container = abjad.Container(r"\time 3/4 r4 r4 r4")
         >>> auxjad.rests_to_multimeasure_rest(container)
@@ -59,6 +59,9 @@ def rests_to_multimeasure_rest(container: abjad.Container):
             %%% \time 3/4 %%%
             R1 * 3/4
         }
+
+        .. figure:: ../_images/image-close_container-4.png
+
         >>> staff = abjad.Staff([container])
         >>> abjad.f(container)
         {
@@ -66,7 +69,9 @@ def rests_to_multimeasure_rest(container: abjad.Container):
             R1 * 3/4
         }
 
-    Example:
+        .. figure:: ../_images/image-close_container-5.png
+
+    Time signature changes:
         Works with containers with multiple time signatures as well as notes.
 
         >>> container = abjad.Staff(r"\time 3/4 r2. | "
@@ -90,7 +95,7 @@ def rests_to_multimeasure_rest(container: abjad.Container):
 
         .. figure:: ../_images/image-rests_to_multimeasure_rest-6.png
 
-    Example:
+    Tuplets:
         Works with containers with tuplets.
 
         >>> container = abjad.Container(r"\times 2/3 {r2 r2 r2}")
@@ -143,9 +148,18 @@ def rests_to_multimeasure_rest(container: abjad.Container):
         }
 
         .. figure:: ../_images/image-rests_to_multimeasure_rest-10.png
+
+    ..  warning::
+
+        The input container must be a contiguous logical voice. When dealing
+        with a container with multiple subcontainers (e.g. a score containings
+        multiple staves), the best approach is to cycle through these
+        subcontainers, applying this function to them individually.
     """
     if not isinstance(container, abjad.Container):
         raise TypeError("argument must be 'abjad.Container' or child class")
+    if not abjad.select(container).leaves().are_contiguous_logical_voice():
+        raise ValueError("argument must be contiguous logical voice")
 
     remove_empty_tuplets(container)
     measures = abjad.select(container[:]).group_by_measure()
